/**
 * @fileoverview jQuery to Rx helpers
 * @author roger.castillo@loku.com (Roger Castillo)
 */


var Rx = require('rx').Rx;
var jsdom = require('jsdom');
var _ = require('underscore');
var URL = require('url');

/**
 * Creates an observable sequence of jQuery elements generated by selector on
 * body
 * @param {String} body
 * @param {String} selector
 */
function createObservablejQuery(body, selector) {
  return Rx.Observable.Create(function(obs){
    try {
      //console.log('parsing body for selector:' + selector);
      jsdom.env(
        {html: body,
        scripts: ['http://code.jquery.com/jquery-1.5.min.js']
        },
      function (err, window) {
        //console.log('Inside jquery');
        var $ = window.jQuery;
        
        // ToDo: Handle empty case
        var es = $(selector);
        if (es && es.length == 0) {
          obs.OnCompleted();
        } else {
          // emit each selected element
          $.each(es, function(k, v){
            obs.OnNext($(this));
            if (k == (es.length - 1)) {
              obs.OnCompleted();
            }
          });
        }
      });// end jsdom
      
    } catch (e){
      //console.log('error!');
      obs.OnCompleted();
    }
    return function(){};
  });
}

exports.createObservablejQuery = createObservablejQuery;